#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2014 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
Code-generated omero.model.Frequency implementation,
based on omero.model.PermissionsI
"""


from builtins import str
from past.builtins import basestring
import Ice
import IceImport
IceImport.load("omero_model_Frequency_ice")
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"

from omero_model_UnitBase import UnitBase
from omero.model.enums import UnitsFrequency

from omero.conversions import Add  # nopep8
from omero.conversions import Int  # nopep8
from omero.conversions import Mul  # nopep8
from omero.conversions import Pow  # nopep8
from omero.conversions import Rat  # nopep8
from omero.conversions import Sym  # nopep8


class FrequencyI(_omero_model.Frequency, UnitBase):

    UNIT_VALUES = sorted(UnitsFrequency._enumerators.values())
    CONVERSIONS = dict()
    for val in UNIT_VALUES:
        CONVERSIONS[val] = dict()
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 6), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Int(1000), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ATTOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("attohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 16), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 13), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Int(100)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 4), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Int(10), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 7), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 10), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 22), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 26)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 19), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.CENTIHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("centihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 19), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Int(1000), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Int(100), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 16), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Int(10), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Int(100)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 7), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 4), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 10), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 13), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 25), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 22), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("decahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 17), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Int(10), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Int(100)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 14), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 5), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Int(100), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 8), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 11), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 23), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 25)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 20), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.DECIHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("decihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 36), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 20), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 17), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 19), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 33), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Pow(10, 9), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 16), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 18), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 15), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Pow(10, 12), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 24), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 21), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 27), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Int(1000), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 30), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Pow(10, 6), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 42), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 39), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.EXAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("exahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Int(1000), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 17)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 9), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 6), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.FEMTOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("femtohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 27), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 11), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 8), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 10), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 24), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 7), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 9), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 6), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Int(1000), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 15), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 12), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 18), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 21), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 33), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 30), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.GIGAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("gigahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 20), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 4), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Int(10), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Int(1000), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 16)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 17), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Int(100), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 8), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 5), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 11), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 14), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 26), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 23), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HECTOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("hectohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 18), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Int(100), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Int(10), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 15), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Int(100)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 6), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Int(1000), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 9), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 12), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 24), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 21), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.HERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("hz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 21), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 5), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Int(100), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 4), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 18), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Int(10), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Int(1000), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 9), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 6), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 12), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 15), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 27), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 24), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.KILOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("kilohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 24), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 8), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 5), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 7), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 21), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 4), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 6), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Int(1000), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 12), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 9), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 15), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 18), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 30), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 27), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MEGAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("megahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 12), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 9), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Int(1000), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 6), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 18), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 15), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MICROHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("microhz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 15), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Int(10)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 4)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Int(100)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 12), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 5)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Int(1000), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 6), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 9), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 21), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 18), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.MILLIHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("millihz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 9), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 7)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 8)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 6), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Int(1000), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 15), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 12), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.NANOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("nanohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 33), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 17), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 14), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 16), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 30), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Pow(10, 6), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 13), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 15), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 12), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Pow(10, 9), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 21), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 18), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 24), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 27), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Int(1000), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 39), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 36), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PETAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("petahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 6), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 10)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 13)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 11)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Int(1000), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 14)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 12), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 9), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.PICOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("picohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 30), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 14), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 11), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 13), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 27), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Int(1000), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 10), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 12), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 9), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Pow(10, 6), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 18), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 15), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 21), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 24), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 36), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 33), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.TERAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("terahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 25)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 26)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 48)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOCTOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 45)), Sym("yoctohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 42), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 26), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 23), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 25), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Pow(10, 6), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 39), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Pow(10, 15), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 22), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 24), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 21), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Pow(10, 18), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 30), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 27), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 33), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Pow(10, 9), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 36), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Pow(10, 12), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 48), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 45), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.YOTTAHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Int(1000), Sym("yottahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 19)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 22)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 20)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 39)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 6)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 30)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 23)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Rat(Int(1), Pow(10, 21)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 24)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 27)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 15)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 18)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 12)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 36)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 9)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 33)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Int(1000), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 45)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZEPTOHERTZ][UnitsFrequency.ZETTAHERTZ] = \
        Mul(Rat(Int(1), Pow(10, 42)), Sym("zeptohz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.ATTOHERTZ] = \
        Mul(Pow(10, 39), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.CENTIHERTZ] = \
        Mul(Pow(10, 23), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.DECAHERTZ] = \
        Mul(Pow(10, 20), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.DECIHERTZ] = \
        Mul(Pow(10, 22), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.EXAHERTZ] = \
        Mul(Int(1000), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.FEMTOHERTZ] = \
        Mul(Pow(10, 36), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.GIGAHERTZ] = \
        Mul(Pow(10, 12), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.HECTOHERTZ] = \
        Mul(Pow(10, 19), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.HERTZ] = \
        Mul(Pow(10, 21), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.KILOHERTZ] = \
        Mul(Pow(10, 18), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.MEGAHERTZ] = \
        Mul(Pow(10, 15), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.MICROHERTZ] = \
        Mul(Pow(10, 27), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.MILLIHERTZ] = \
        Mul(Pow(10, 24), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.NANOHERTZ] = \
        Mul(Pow(10, 30), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.PETAHERTZ] = \
        Mul(Pow(10, 6), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.PICOHERTZ] = \
        Mul(Pow(10, 33), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.TERAHERTZ] = \
        Mul(Pow(10, 9), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.YOCTOHERTZ] = \
        Mul(Pow(10, 45), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.YOTTAHERTZ] = \
        Mul(Rat(Int(1), Int(1000)), Sym("zettahz"))  # nopep8
    CONVERSIONS[UnitsFrequency.ZETTAHERTZ][UnitsFrequency.ZEPTOHERTZ] = \
        Mul(Pow(10, 42), Sym("zettahz"))  # nopep8
    del val

    SYMBOLS = dict()
    SYMBOLS["ATTOHERTZ"] = "aHz"
    SYMBOLS["CENTIHERTZ"] = "cHz"
    SYMBOLS["DECAHERTZ"] = "daHz"
    SYMBOLS["DECIHERTZ"] = "dHz"
    SYMBOLS["EXAHERTZ"] = "EHz"
    SYMBOLS["FEMTOHERTZ"] = "fHz"
    SYMBOLS["GIGAHERTZ"] = "GHz"
    SYMBOLS["HECTOHERTZ"] = "hHz"
    SYMBOLS["HERTZ"] = "Hz"
    SYMBOLS["KILOHERTZ"] = "kHz"
    SYMBOLS["MEGAHERTZ"] = "MHz"
    SYMBOLS["MICROHERTZ"] = "µHz"
    SYMBOLS["MILLIHERTZ"] = "mHz"
    SYMBOLS["NANOHERTZ"] = "nHz"
    SYMBOLS["PETAHERTZ"] = "PHz"
    SYMBOLS["PICOHERTZ"] = "pHz"
    SYMBOLS["TERAHERTZ"] = "THz"
    SYMBOLS["YOCTOHERTZ"] = "yHz"
    SYMBOLS["YOTTAHERTZ"] = "YHz"
    SYMBOLS["ZEPTOHERTZ"] = "zHz"
    SYMBOLS["ZETTAHERTZ"] = "ZHz"

    def __init__(self, value=None, unit=None):
        _omero_model.Frequency.__init__(self)

        if unit is None:
            target = None
        elif isinstance(unit, UnitsFrequency):
            target = unit
        elif isinstance(unit, basestring):
            target = getattr(UnitsFrequency, unit)
        else:
            raise Exception("Unknown unit: %s (%s)" % (
                unit, type(unit)
            ))

        if isinstance(value, _omero_model.FrequencyI):
            # This is a copy-constructor call.

            source = value.getUnit()

            if target is None:
                raise Exception("Null target unit")
            if source is None:
                raise Exception("Null source unit")

            if target == source:
                self.setValue(value.getValue())
                self.setUnit(source)
            else:
                c = self.CONVERSIONS.get(source).get(target)
                if c is None:
                    t = (value.getValue(), source, target)
                    msg = "%s %s cannot be converted to %s" % t
                    raise Exception(msg)
                self.setValue(c(value.getValue()))
                self.setUnit(target)
        else:
            self.setValue(value)
            self.setUnit(target)

    def getUnit(self, current=None):
        return self._unit

    def getValue(self, current=None):
        return self._value

    def getSymbol(self, current=None):
        return self.SYMBOLS.get(str(self.getUnit()))

    @staticmethod
    def lookupSymbol(unit):
        return FrequencyI.SYMBOLS.get(str(unit))

    def setUnit(self, unit, current=None):
        self._unit = unit

    def setValue(self, value, current=None):
        self._value = value

    def __str__(self):
        return self._base_string(self.getValue(), self.getUnit())

_omero_model.FrequencyI = FrequencyI



#!/usr/bin/env python
# -*- coding: utf-8 -*-

#
# Copyright (C) 2014 Glencoe Software, Inc. All Rights Reserved.
# Use is subject to license terms supplied in LICENSE.txt
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
# the Free Software Foundation; either version 2 of the License, or
# (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License along
# with this program; if not, write to the Free Software Foundation, Inc.,
# 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

"""
Code-generated omero.model.Temperature implementation,
based on omero.model.PermissionsI
"""


from builtins import str
from past.builtins import basestring
import Ice
import IceImport
IceImport.load("omero_model_Temperature_ice")
_omero = Ice.openModule("omero")
_omero_model = Ice.openModule("omero.model")
__name__ = "omero.model"

from omero_model_UnitBase import UnitBase
from omero.model.enums import UnitsTemperature

from omero.conversions import Add  # nopep8
from omero.conversions import Int  # nopep8
from omero.conversions import Mul  # nopep8
from omero.conversions import Pow  # nopep8
from omero.conversions import Rat  # nopep8
from omero.conversions import Sym  # nopep8


class TemperatureI(_omero_model.Temperature, UnitBase):

    UNIT_VALUES = sorted(UnitsTemperature._enumerators.values())
    CONVERSIONS = dict()
    for val in UNIT_VALUES:
        CONVERSIONS[val] = dict()
    CONVERSIONS[UnitsTemperature.CELSIUS][UnitsTemperature.FAHRENHEIT] = \
        Add(Mul(Rat(Int(9), Int(5)), Sym("c")), Int(32))  # nopep8
    CONVERSIONS[UnitsTemperature.CELSIUS][UnitsTemperature.KELVIN] = \
        Add(Sym("c"), Rat(Int(5463), Int(20)))  # nopep8
    CONVERSIONS[UnitsTemperature.CELSIUS][UnitsTemperature.RANKINE] = \
        Add(Mul(Rat(Int(9), Int(5)), Sym("c")), Rat(Int(49167), Int(100)))  # nopep8
    CONVERSIONS[UnitsTemperature.FAHRENHEIT][UnitsTemperature.CELSIUS] = \
        Add(Mul(Rat(Int(5), Int(9)), Sym("f")), Rat(Int(-160), Int(9)))  # nopep8
    CONVERSIONS[UnitsTemperature.FAHRENHEIT][UnitsTemperature.KELVIN] = \
        Add(Mul(Rat(Int(5), Int(9)), Sym("f")), Rat(Int(45967), Int(180)))  # nopep8
    CONVERSIONS[UnitsTemperature.FAHRENHEIT][UnitsTemperature.RANKINE] = \
        Add(Sym("f"), Rat(Int(45967), Int(100)))  # nopep8
    CONVERSIONS[UnitsTemperature.KELVIN][UnitsTemperature.CELSIUS] = \
        Add(Sym("k"), Rat(Int(-5463), Int(20)))  # nopep8
    CONVERSIONS[UnitsTemperature.KELVIN][UnitsTemperature.FAHRENHEIT] = \
        Add(Mul(Rat(Int(9), Int(5)), Sym("k")), Rat(Int(-45967), Int(100)))  # nopep8
    CONVERSIONS[UnitsTemperature.KELVIN][UnitsTemperature.RANKINE] = \
        Mul(Rat(Int(9), Int(5)), Sym("k"))  # nopep8
    CONVERSIONS[UnitsTemperature.RANKINE][UnitsTemperature.CELSIUS] = \
        Add(Mul(Rat(Int(5), Int(9)), Sym("r")), Rat(Int(-5463), Int(20)))  # nopep8
    CONVERSIONS[UnitsTemperature.RANKINE][UnitsTemperature.FAHRENHEIT] = \
        Add(Sym("r"), Rat(Int(-45967), Int(100)))  # nopep8
    CONVERSIONS[UnitsTemperature.RANKINE][UnitsTemperature.KELVIN] = \
        Mul(Rat(Int(5), Int(9)), Sym("r"))  # nopep8
    del val

    SYMBOLS = dict()
    SYMBOLS["CELSIUS"] = "°C"
    SYMBOLS["FAHRENHEIT"] = "°F"
    SYMBOLS["KELVIN"] = "K"
    SYMBOLS["RANKINE"] = "°R"

    def __init__(self, value=None, unit=None):
        _omero_model.Temperature.__init__(self)

        if unit is None:
            target = None
        elif isinstance(unit, UnitsTemperature):
            target = unit
        elif isinstance(unit, basestring):
            target = getattr(UnitsTemperature, unit)
        else:
            raise Exception("Unknown unit: %s (%s)" % (
                unit, type(unit)
            ))

        if isinstance(value, _omero_model.TemperatureI):
            # This is a copy-constructor call.

            source = value.getUnit()

            if target is None:
                raise Exception("Null target unit")
            if source is None:
                raise Exception("Null source unit")

            if target == source:
                self.setValue(value.getValue())
                self.setUnit(source)
            else:
                c = self.CONVERSIONS.get(source).get(target)
                if c is None:
                    t = (value.getValue(), source, target)
                    msg = "%s %s cannot be converted to %s" % t
                    raise Exception(msg)
                self.setValue(c(value.getValue()))
                self.setUnit(target)
        else:
            self.setValue(value)
            self.setUnit(target)

    def getUnit(self, current=None):
        return self._unit

    def getValue(self, current=None):
        return self._value

    def getSymbol(self, current=None):
        return self.SYMBOLS.get(str(self.getUnit()))

    @staticmethod
    def lookupSymbol(unit):
        return TemperatureI.SYMBOLS.get(str(unit))

    def setUnit(self, unit, current=None):
        self._unit = unit

    def setValue(self, value, current=None):
        self._value = value

    def __str__(self):
        return self._base_string(self.getValue(), self.getUnit())

_omero_model.TemperatureI = TemperatureI



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `Laser.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice
import omero_model_LightSource_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'LaserType' not in _M_omero.model.__dict__:
    _M_omero.model._t_LaserType = IcePy.declareClass('::omero::model::LaserType')
    _M_omero.model._t_LaserTypePrx = IcePy.declareProxy('::omero::model::LaserType')

if 'LaserMedium' not in _M_omero.model.__dict__:
    _M_omero.model._t_LaserMedium = IcePy.declareClass('::omero::model::LaserMedium')
    _M_omero.model._t_LaserMediumPrx = IcePy.declareProxy('::omero::model::LaserMedium')

if 'Pulse' not in _M_omero.model.__dict__:
    _M_omero.model._t_Pulse = IcePy.declareClass('::omero::model::Pulse')
    _M_omero.model._t_PulsePrx = IcePy.declareProxy('::omero::model::Pulse')

if 'Length' not in _M_omero.model.__dict__:
    _M_omero.model._t_Length = IcePy.declareClass('::omero::model::Length')
    _M_omero.model._t_LengthPrx = IcePy.declareProxy('::omero::model::Length')

if 'LightSource' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSource = IcePy.declareClass('::omero::model::LightSource')
    _M_omero.model._t_LightSourcePrx = IcePy.declareProxy('::omero::model::LightSource')

if 'Frequency' not in _M_omero.model.__dict__:
    _M_omero.model._t_Frequency = IcePy.declareClass('::omero::model::Frequency')
    _M_omero.model._t_FrequencyPrx = IcePy.declareProxy('::omero::model::Frequency')

if 'Power' not in _M_omero.model.__dict__:
    _M_omero.model._t_Power = IcePy.declareClass('::omero::model::Power')
    _M_omero.model._t_PowerPrx = IcePy.declareProxy('::omero::model::Power')

if 'Instrument' not in _M_omero.model.__dict__:
    _M_omero.model._t_Instrument = IcePy.declareClass('::omero::model::Instrument')
    _M_omero.model._t_InstrumentPrx = IcePy.declareProxy('::omero::model::Instrument')

if 'LightSourceAnnotationLink' not in _M_omero.model.__dict__:
    _M_omero.model._t_LightSourceAnnotationLink = IcePy.declareClass('::omero::model::LightSourceAnnotationLink')
    _M_omero.model._t_LightSourceAnnotationLinkPrx = IcePy.declareProxy('::omero::model::LightSourceAnnotationLink')

if 'Annotation' not in _M_omero.model.__dict__:
    _M_omero.model._t_Annotation = IcePy.declareClass('::omero::model::Annotation')
    _M_omero.model._t_AnnotationPrx = IcePy.declareProxy('::omero::model::Annotation')

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'Laser' not in _M_omero.model.__dict__:
    _M_omero.model.Laser = Ice.createTempClass()
    class Laser(_M_omero.model.LightSource):
        def __init__(self, _id=None, _details=None, _loaded=False, _version=None, _manufacturer=None, _model=None, _power=None, _lotNumber=None, _serialNumber=None, _instrument=None, _annotationLinksSeq=None, _annotationLinksLoaded=False, _annotationLinksCountPerOwner=None, _type=None, _laserMedium=None, _frequencyMultiplication=None, _tuneable=None, _pulse=None, _wavelength=None, _pockelCell=None, _pump=None, _repetitionRate=None):
            if Ice.getType(self) == _M_omero.model.Laser:
                raise RuntimeError('omero.model.Laser is an abstract class')
            _M_omero.model.LightSource.__init__(self, _id, _details, _loaded, _version, _manufacturer, _model, _power, _lotNumber, _serialNumber, _instrument, _annotationLinksSeq, _annotationLinksLoaded, _annotationLinksCountPerOwner)
            self._type = _type
            self._laserMedium = _laserMedium
            self._frequencyMultiplication = _frequencyMultiplication
            self._tuneable = _tuneable
            self._pulse = _pulse
            self._wavelength = _wavelength
            self._pockelCell = _pockelCell
            self._pump = _pump
            self._repetitionRate = _repetitionRate

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::IObject', '::omero::model::Laser', '::omero::model::LightSource')

        def ice_id(self, current=None):
            return '::omero::model::Laser'

        def ice_staticId():
            return '::omero::model::Laser'
        ice_staticId = staticmethod(ice_staticId)

        def getType(self, current=None):
            pass

        def setType(self, theType, current=None):
            pass

        def getLaserMedium(self, current=None):
            pass

        def setLaserMedium(self, theLaserMedium, current=None):
            pass

        def getFrequencyMultiplication(self, current=None):
            pass

        def setFrequencyMultiplication(self, theFrequencyMultiplication, current=None):
            pass

        def getTuneable(self, current=None):
            pass

        def setTuneable(self, theTuneable, current=None):
            pass

        def getPulse(self, current=None):
            pass

        def setPulse(self, thePulse, current=None):
            pass

        def getWavelength(self, current=None):
            pass

        def setWavelength(self, theWavelength, current=None):
            pass

        def getPockelCell(self, current=None):
            pass

        def setPockelCell(self, thePockelCell, current=None):
            pass

        def getPump(self, current=None):
            pass

        def setPump(self, thePump, current=None):
            pass

        def getRepetitionRate(self, current=None):
            pass

        def setRepetitionRate(self, theRepetitionRate, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_Laser)

        __repr__ = __str__

    _M_omero.model.LaserPrx = Ice.createTempClass()
    class LaserPrx(_M_omero.model.LightSourcePrx):

        def getType(self, _ctx=None):
            return _M_omero.model.Laser._op_getType.invoke(self, ((), _ctx))

        def begin_getType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getType(self, _r):
            return _M_omero.model.Laser._op_getType.end(self, _r)

        def setType(self, theType, _ctx=None):
            return _M_omero.model.Laser._op_setType.invoke(self, ((theType, ), _ctx))

        def begin_setType(self, theType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setType.begin(self, ((theType, ), _response, _ex, _sent, _ctx))

        def end_setType(self, _r):
            return _M_omero.model.Laser._op_setType.end(self, _r)

        def getLaserMedium(self, _ctx=None):
            return _M_omero.model.Laser._op_getLaserMedium.invoke(self, ((), _ctx))

        def begin_getLaserMedium(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getLaserMedium.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLaserMedium(self, _r):
            return _M_omero.model.Laser._op_getLaserMedium.end(self, _r)

        def setLaserMedium(self, theLaserMedium, _ctx=None):
            return _M_omero.model.Laser._op_setLaserMedium.invoke(self, ((theLaserMedium, ), _ctx))

        def begin_setLaserMedium(self, theLaserMedium, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setLaserMedium.begin(self, ((theLaserMedium, ), _response, _ex, _sent, _ctx))

        def end_setLaserMedium(self, _r):
            return _M_omero.model.Laser._op_setLaserMedium.end(self, _r)

        def getFrequencyMultiplication(self, _ctx=None):
            return _M_omero.model.Laser._op_getFrequencyMultiplication.invoke(self, ((), _ctx))

        def begin_getFrequencyMultiplication(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getFrequencyMultiplication.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getFrequencyMultiplication(self, _r):
            return _M_omero.model.Laser._op_getFrequencyMultiplication.end(self, _r)

        def setFrequencyMultiplication(self, theFrequencyMultiplication, _ctx=None):
            return _M_omero.model.Laser._op_setFrequencyMultiplication.invoke(self, ((theFrequencyMultiplication, ), _ctx))

        def begin_setFrequencyMultiplication(self, theFrequencyMultiplication, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setFrequencyMultiplication.begin(self, ((theFrequencyMultiplication, ), _response, _ex, _sent, _ctx))

        def end_setFrequencyMultiplication(self, _r):
            return _M_omero.model.Laser._op_setFrequencyMultiplication.end(self, _r)

        def getTuneable(self, _ctx=None):
            return _M_omero.model.Laser._op_getTuneable.invoke(self, ((), _ctx))

        def begin_getTuneable(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getTuneable.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getTuneable(self, _r):
            return _M_omero.model.Laser._op_getTuneable.end(self, _r)

        def setTuneable(self, theTuneable, _ctx=None):
            return _M_omero.model.Laser._op_setTuneable.invoke(self, ((theTuneable, ), _ctx))

        def begin_setTuneable(self, theTuneable, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setTuneable.begin(self, ((theTuneable, ), _response, _ex, _sent, _ctx))

        def end_setTuneable(self, _r):
            return _M_omero.model.Laser._op_setTuneable.end(self, _r)

        def getPulse(self, _ctx=None):
            return _M_omero.model.Laser._op_getPulse.invoke(self, ((), _ctx))

        def begin_getPulse(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getPulse.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPulse(self, _r):
            return _M_omero.model.Laser._op_getPulse.end(self, _r)

        def setPulse(self, thePulse, _ctx=None):
            return _M_omero.model.Laser._op_setPulse.invoke(self, ((thePulse, ), _ctx))

        def begin_setPulse(self, thePulse, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setPulse.begin(self, ((thePulse, ), _response, _ex, _sent, _ctx))

        def end_setPulse(self, _r):
            return _M_omero.model.Laser._op_setPulse.end(self, _r)

        def getWavelength(self, _ctx=None):
            return _M_omero.model.Laser._op_getWavelength.invoke(self, ((), _ctx))

        def begin_getWavelength(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getWavelength.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getWavelength(self, _r):
            return _M_omero.model.Laser._op_getWavelength.end(self, _r)

        def setWavelength(self, theWavelength, _ctx=None):
            return _M_omero.model.Laser._op_setWavelength.invoke(self, ((theWavelength, ), _ctx))

        def begin_setWavelength(self, theWavelength, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setWavelength.begin(self, ((theWavelength, ), _response, _ex, _sent, _ctx))

        def end_setWavelength(self, _r):
            return _M_omero.model.Laser._op_setWavelength.end(self, _r)

        def getPockelCell(self, _ctx=None):
            return _M_omero.model.Laser._op_getPockelCell.invoke(self, ((), _ctx))

        def begin_getPockelCell(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getPockelCell.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPockelCell(self, _r):
            return _M_omero.model.Laser._op_getPockelCell.end(self, _r)

        def setPockelCell(self, thePockelCell, _ctx=None):
            return _M_omero.model.Laser._op_setPockelCell.invoke(self, ((thePockelCell, ), _ctx))

        def begin_setPockelCell(self, thePockelCell, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setPockelCell.begin(self, ((thePockelCell, ), _response, _ex, _sent, _ctx))

        def end_setPockelCell(self, _r):
            return _M_omero.model.Laser._op_setPockelCell.end(self, _r)

        def getPump(self, _ctx=None):
            return _M_omero.model.Laser._op_getPump.invoke(self, ((), _ctx))

        def begin_getPump(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getPump.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getPump(self, _r):
            return _M_omero.model.Laser._op_getPump.end(self, _r)

        def setPump(self, thePump, _ctx=None):
            return _M_omero.model.Laser._op_setPump.invoke(self, ((thePump, ), _ctx))

        def begin_setPump(self, thePump, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setPump.begin(self, ((thePump, ), _response, _ex, _sent, _ctx))

        def end_setPump(self, _r):
            return _M_omero.model.Laser._op_setPump.end(self, _r)

        def getRepetitionRate(self, _ctx=None):
            return _M_omero.model.Laser._op_getRepetitionRate.invoke(self, ((), _ctx))

        def begin_getRepetitionRate(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_getRepetitionRate.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getRepetitionRate(self, _r):
            return _M_omero.model.Laser._op_getRepetitionRate.end(self, _r)

        def setRepetitionRate(self, theRepetitionRate, _ctx=None):
            return _M_omero.model.Laser._op_setRepetitionRate.invoke(self, ((theRepetitionRate, ), _ctx))

        def begin_setRepetitionRate(self, theRepetitionRate, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.Laser._op_setRepetitionRate.begin(self, ((theRepetitionRate, ), _response, _ex, _sent, _ctx))

        def end_setRepetitionRate(self, _r):
            return _M_omero.model.Laser._op_setRepetitionRate.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.LaserPrx.ice_checkedCast(proxy, '::omero::model::Laser', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.LaserPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::Laser'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_LaserPrx = IcePy.defineProxy('::omero::model::Laser', LaserPrx)

    _M_omero.model._t_Laser = IcePy.declareClass('::omero::model::Laser')

    _M_omero.model._t_Laser = IcePy.defineClass('::omero::model::Laser', Laser, -1, (), True, False, _M_omero.model._t_LightSource, (), (
        ('_type', (), _M_omero.model._t_LaserType, False, 0),
        ('_laserMedium', (), _M_omero.model._t_LaserMedium, False, 0),
        ('_frequencyMultiplication', (), _M_omero._t_RInt, False, 0),
        ('_tuneable', (), _M_omero._t_RBool, False, 0),
        ('_pulse', (), _M_omero.model._t_Pulse, False, 0),
        ('_wavelength', (), _M_omero.model._t_Length, False, 0),
        ('_pockelCell', (), _M_omero._t_RBool, False, 0),
        ('_pump', (), _M_omero.model._t_LightSource, False, 0),
        ('_repetitionRate', (), _M_omero.model._t_Frequency, False, 0)
    ))
    Laser._ice_type = _M_omero.model._t_Laser

    Laser._op_getType = IcePy.Operation('getType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LaserType, False, 0), ())
    Laser._op_setType = IcePy.Operation('setType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LaserType, False, 0),), (), None, ())
    Laser._op_getLaserMedium = IcePy.Operation('getLaserMedium', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LaserMedium, False, 0), ())
    Laser._op_setLaserMedium = IcePy.Operation('setLaserMedium', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LaserMedium, False, 0),), (), None, ())
    Laser._op_getFrequencyMultiplication = IcePy.Operation('getFrequencyMultiplication', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RInt, False, 0), ())
    Laser._op_setFrequencyMultiplication = IcePy.Operation('setFrequencyMultiplication', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RInt, False, 0),), (), None, ())
    Laser._op_getTuneable = IcePy.Operation('getTuneable', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    Laser._op_setTuneable = IcePy.Operation('setTuneable', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    Laser._op_getPulse = IcePy.Operation('getPulse', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Pulse, False, 0), ())
    Laser._op_setPulse = IcePy.Operation('setPulse', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Pulse, False, 0),), (), None, ())
    Laser._op_getWavelength = IcePy.Operation('getWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Length, False, 0), ())
    Laser._op_setWavelength = IcePy.Operation('setWavelength', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Length, False, 0),), (), None, ())
    Laser._op_getPockelCell = IcePy.Operation('getPockelCell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RBool, False, 0), ())
    Laser._op_setPockelCell = IcePy.Operation('setPockelCell', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RBool, False, 0),), (), None, ())
    Laser._op_getPump = IcePy.Operation('getPump', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_LightSource, False, 0), ())
    Laser._op_setPump = IcePy.Operation('setPump', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_LightSource, False, 0),), (), None, ())
    Laser._op_getRepetitionRate = IcePy.Operation('getRepetitionRate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero.model._t_Frequency, False, 0), ())
    Laser._op_setRepetitionRate = IcePy.Operation('setRepetitionRate', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero.model._t_Frequency, False, 0),), (), None, ())

    _M_omero.model.Laser = Laser
    del Laser

    _M_omero.model.LaserPrx = LaserPrx
    del LaserPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero



# -*- coding: utf-8 -*-
# **********************************************************************
#
# Copyright (c) 2003-2017 ZeroC, Inc. All rights reserved.
#
# This copy of Ice is licensed to you under the terms described in the
# ICE_LICENSE file included in this distribution.
#
# **********************************************************************
#
# Ice version 3.6.4
#
# <auto-generated>
#
# Generated from file `ExternalInfo.ice'
#
# Warning: do not edit this file.
#
# </auto-generated>
#

from sys import version_info as _version_info_
import Ice, IcePy
import omero_model_IObject_ice
import omero_RTypes_ice
import omero_model_RTypes_ice
import omero_System_ice
import omero_Collections_ice

# Included module omero
_M_omero = Ice.openModule('omero')

# Included module omero.model
_M_omero.model = Ice.openModule('omero.model')

# Included module Ice
_M_Ice = Ice.openModule('Ice')

# Included module omero.sys
_M_omero.sys = Ice.openModule('omero.sys')

# Included module omero.api
_M_omero.api = Ice.openModule('omero.api')

# Start of module omero
__name__ = 'omero'

# Start of module omero.model
__name__ = 'omero.model'

if 'Details' not in _M_omero.model.__dict__:
    _M_omero.model._t_Details = IcePy.declareClass('::omero::model::Details')
    _M_omero.model._t_DetailsPrx = IcePy.declareProxy('::omero::model::Details')

if 'ExternalInfo' not in _M_omero.model.__dict__:
    _M_omero.model.ExternalInfo = Ice.createTempClass()
    class ExternalInfo(_M_omero.model.IObject):
        def __init__(self, _id=None, _details=None, _loaded=False, _entityId=None, _entityType=None, _lsid=None, _uuid=None):
            if Ice.getType(self) == _M_omero.model.ExternalInfo:
                raise RuntimeError('omero.model.ExternalInfo is an abstract class')
            _M_omero.model.IObject.__init__(self, _id, _details, _loaded)
            self._entityId = _entityId
            self._entityType = _entityType
            self._lsid = _lsid
            self._uuid = _uuid

        def ice_ids(self, current=None):
            return ('::Ice::Object', '::omero::model::ExternalInfo', '::omero::model::IObject')

        def ice_id(self, current=None):
            return '::omero::model::ExternalInfo'

        def ice_staticId():
            return '::omero::model::ExternalInfo'
        ice_staticId = staticmethod(ice_staticId)

        def getEntityId(self, current=None):
            pass

        def setEntityId(self, theEntityId, current=None):
            pass

        def getEntityType(self, current=None):
            pass

        def setEntityType(self, theEntityType, current=None):
            pass

        def getLsid(self, current=None):
            pass

        def setLsid(self, theLsid, current=None):
            pass

        def getUuid(self, current=None):
            pass

        def setUuid(self, theUuid, current=None):
            pass

        def __str__(self):
            return IcePy.stringify(self, _M_omero.model._t_ExternalInfo)

        __repr__ = __str__

    _M_omero.model.ExternalInfoPrx = Ice.createTempClass()
    class ExternalInfoPrx(_M_omero.model.IObjectPrx):

        def getEntityId(self, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getEntityId.invoke(self, ((), _ctx))

        def begin_getEntityId(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getEntityId.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEntityId(self, _r):
            return _M_omero.model.ExternalInfo._op_getEntityId.end(self, _r)

        def setEntityId(self, theEntityId, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setEntityId.invoke(self, ((theEntityId, ), _ctx))

        def begin_setEntityId(self, theEntityId, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setEntityId.begin(self, ((theEntityId, ), _response, _ex, _sent, _ctx))

        def end_setEntityId(self, _r):
            return _M_omero.model.ExternalInfo._op_setEntityId.end(self, _r)

        def getEntityType(self, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getEntityType.invoke(self, ((), _ctx))

        def begin_getEntityType(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getEntityType.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getEntityType(self, _r):
            return _M_omero.model.ExternalInfo._op_getEntityType.end(self, _r)

        def setEntityType(self, theEntityType, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setEntityType.invoke(self, ((theEntityType, ), _ctx))

        def begin_setEntityType(self, theEntityType, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setEntityType.begin(self, ((theEntityType, ), _response, _ex, _sent, _ctx))

        def end_setEntityType(self, _r):
            return _M_omero.model.ExternalInfo._op_setEntityType.end(self, _r)

        def getLsid(self, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getLsid.invoke(self, ((), _ctx))

        def begin_getLsid(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getLsid.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getLsid(self, _r):
            return _M_omero.model.ExternalInfo._op_getLsid.end(self, _r)

        def setLsid(self, theLsid, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setLsid.invoke(self, ((theLsid, ), _ctx))

        def begin_setLsid(self, theLsid, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setLsid.begin(self, ((theLsid, ), _response, _ex, _sent, _ctx))

        def end_setLsid(self, _r):
            return _M_omero.model.ExternalInfo._op_setLsid.end(self, _r)

        def getUuid(self, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getUuid.invoke(self, ((), _ctx))

        def begin_getUuid(self, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_getUuid.begin(self, ((), _response, _ex, _sent, _ctx))

        def end_getUuid(self, _r):
            return _M_omero.model.ExternalInfo._op_getUuid.end(self, _r)

        def setUuid(self, theUuid, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setUuid.invoke(self, ((theUuid, ), _ctx))

        def begin_setUuid(self, theUuid, _response=None, _ex=None, _sent=None, _ctx=None):
            return _M_omero.model.ExternalInfo._op_setUuid.begin(self, ((theUuid, ), _response, _ex, _sent, _ctx))

        def end_setUuid(self, _r):
            return _M_omero.model.ExternalInfo._op_setUuid.end(self, _r)

        def checkedCast(proxy, facetOrCtx=None, _ctx=None):
            return _M_omero.model.ExternalInfoPrx.ice_checkedCast(proxy, '::omero::model::ExternalInfo', facetOrCtx, _ctx)
        checkedCast = staticmethod(checkedCast)

        def uncheckedCast(proxy, facet=None):
            return _M_omero.model.ExternalInfoPrx.ice_uncheckedCast(proxy, facet)
        uncheckedCast = staticmethod(uncheckedCast)

        def ice_staticId():
            return '::omero::model::ExternalInfo'
        ice_staticId = staticmethod(ice_staticId)

    _M_omero.model._t_ExternalInfoPrx = IcePy.defineProxy('::omero::model::ExternalInfo', ExternalInfoPrx)

    _M_omero.model._t_ExternalInfo = IcePy.declareClass('::omero::model::ExternalInfo')

    _M_omero.model._t_ExternalInfo = IcePy.defineClass('::omero::model::ExternalInfo', ExternalInfo, -1, (), True, False, _M_omero.model._t_IObject, (), (
        ('_entityId', (), _M_omero._t_RLong, False, 0),
        ('_entityType', (), _M_omero._t_RString, False, 0),
        ('_lsid', (), _M_omero._t_RString, False, 0),
        ('_uuid', (), _M_omero._t_RString, False, 0)
    ))
    ExternalInfo._ice_type = _M_omero.model._t_ExternalInfo

    ExternalInfo._op_getEntityId = IcePy.Operation('getEntityId', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RLong, False, 0), ())
    ExternalInfo._op_setEntityId = IcePy.Operation('setEntityId', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RLong, False, 0),), (), None, ())
    ExternalInfo._op_getEntityType = IcePy.Operation('getEntityType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    ExternalInfo._op_setEntityType = IcePy.Operation('setEntityType', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    ExternalInfo._op_getLsid = IcePy.Operation('getLsid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    ExternalInfo._op_setLsid = IcePy.Operation('setLsid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())
    ExternalInfo._op_getUuid = IcePy.Operation('getUuid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (), (), ((), _M_omero._t_RString, False, 0), ())
    ExternalInfo._op_setUuid = IcePy.Operation('setUuid', Ice.OperationMode.Normal, Ice.OperationMode.Normal, False, None, (), (((), _M_omero._t_RString, False, 0),), (), None, ())

    _M_omero.model.ExternalInfo = ExternalInfo
    del ExternalInfo

    _M_omero.model.ExternalInfoPrx = ExternalInfoPrx
    del ExternalInfoPrx

# End of module omero.model

__name__ = 'omero'

# End of module omero
